.. mcfine documentation master file, created by
   sphinx-quickstart on Wed Nov 17 17:27:03 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: intro.rst

.. toctree::
   :maxdepth: 2
   :caption: Documentation

   install
   advanced_topics
   tutorials/single_spectra_fitting
   tutorials/cube_fitting
   changelog
   reference_api

Developers
==========

This package has been developed by:

* Thomas Williams (Oxford)
* Elizabeth Watkins (Manchester)

Citing McFine
=============

If you use McFine in your work, please drop us a citation (Williams & Watkins, in prep.), and provide a footnote to the
package repository (https://github.com/thomaswilliamsastro/mcfine).

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
